@@ -75,13 +75,15 @@ sub init_and_watch {
 
     if($delay =~ /\D/) {
         $WATCHER = Log::Log4perl::Config::Watch->new(
-                          file   => $config,
-                          signal => $delay,
+                          file         => $config,
+                          signal       => $delay,
+                          l4p_internal => 1,
                    );
     } else {
         $WATCHER = Log::Log4perl::Config::Watch->new(
                           file           => $config,
                           check_interval => $delay,
+                          l4p_internal   => 1,
                    );
     }
 
@@ -187,6 +189,11 @@ sub _init {
                     print "Found entry @$path\n" if _INTERNAL_DEBUG;
                     $filter_names{@$path[0]}++;
                 } else {
+
+                    if (ref($value) eq "ARRAY") {
+                      die "Multiple definitions of logger ".join('.',@$path)." in log4perl config";
+                    }
+
                     # This is a regular logger
                     push @loggers, [join('.', @$path), $value];
                 }
@@ -374,7 +381,7 @@ sub create_appender_instance {
                 %param,
             ); 
     
-            for(@$depends_on) {
+            for my $dependency (@$depends_on) {
                 # If this appender indicates that it needs other appenders
                 # to exist (e.g. because it's a composite appender that
                 # relays messages on to its appender-refs) then we're 
@@ -385,7 +392,7 @@ sub create_appender_instance {
                 # appenders.
                 $appender->composite(1);
                 next if exists $appenders_created->{$appname};
-                my $app = create_appender_instance($data, $_, 
+                my $app = create_appender_instance($data, $dependency, 
                              $appenders_created,
                              $post_config_subs);
                 # If the appender appended a subroutine to $post_config_subs
@@ -398,7 +405,7 @@ sub create_appender_instance {
                 # Smuggle this sub-appender into the hash of known appenders 
                 # without attaching it to any logger directly.
                 $
-                Log::Log4perl::Logger::APPENDER_BY_NAME{$_} = $app;
+                Log::Log4perl::Logger::APPENDER_BY_NAME{$dependency} = $app;
             }
         }
     }
@@ -553,7 +560,7 @@ sub config_read {
        require Net::LDAP;
        require Log::Log4perl::Config::LDAPConfigurator;
 
-       return Log::Log4perl::Config::LDAPConfigurator::parse($config);
+       return Log::Log4perl::Config::LDAPConfigurator->new->parse($config);
 
     }else{
 
